==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/kendra_index/KendraIndexUserTokenConfigurations.java <==
package com.hashicorp.cdktf.providers.aws.kendra_index;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.395Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.kendraIndex.KendraIndexUserTokenConfigurations")
@software.amazon.jsii.Jsii.Proxy(KendraIndexUserTokenConfigurations.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface KendraIndexUserTokenConfigurations extends software.amazon.jsii.JsiiSerializable {

    /**
     * json_token_type_configuration block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/kendra_index#json_token_type_configuration KendraIndex#json_token_type_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration getJsonTokenTypeConfiguration() {
        return null;
    }

    /**
     * jwt_token_type_configuration block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/kendra_index#jwt_token_type_configuration KendraIndex#jwt_token_type_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration getJwtTokenTypeConfiguration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link KendraIndexUserTokenConfigurations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link KendraIndexUserTokenConfigurations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<KendraIndexUserTokenConfigurations> {
        com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration jsonTokenTypeConfiguration;
        com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration jwtTokenTypeConfiguration;

        /**
         * Sets the value of {@link KendraIndexUserTokenConfigurations#getJsonTokenTypeConfiguration}
         * @param jsonTokenTypeConfiguration json_token_type_configuration block.
         *                                   Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/kendra_index#json_token_type_configuration KendraIndex#json_token_type_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder jsonTokenTypeConfiguration(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration jsonTokenTypeConfiguration) {
            this.jsonTokenTypeConfiguration = jsonTokenTypeConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link KendraIndexUserTokenConfigurations#getJwtTokenTypeConfiguration}
         * @param jwtTokenTypeConfiguration jwt_token_type_configuration block.
         *                                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/kendra_index#jwt_token_type_configuration KendraIndex#jwt_token_type_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder jwtTokenTypeConfiguration(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration jwtTokenTypeConfiguration) {
            this.jwtTokenTypeConfiguration = jwtTokenTypeConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link KendraIndexUserTokenConfigurations}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public KendraIndexUserTokenConfigurations build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link KendraIndexUserTokenConfigurations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements KendraIndexUserTokenConfigurations {
        private final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration jsonTokenTypeConfiguration;
        private final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration jwtTokenTypeConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.jsonTokenTypeConfiguration = software.amazon.jsii.Kernel.get(this, "jsonTokenTypeConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration.class));
            this.jwtTokenTypeConfiguration = software.amazon.jsii.Kernel.get(this, "jwtTokenTypeConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.jsonTokenTypeConfiguration = builder.jsonTokenTypeConfiguration;
            this.jwtTokenTypeConfiguration = builder.jwtTokenTypeConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration getJsonTokenTypeConfiguration() {
            return this.jsonTokenTypeConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration getJwtTokenTypeConfiguration() {
            return this.jwtTokenTypeConfiguration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getJsonTokenTypeConfiguration() != null) {
                data.set("jsonTokenTypeConfiguration", om.valueToTree(this.getJsonTokenTypeConfiguration()));
            }
            if (this.getJwtTokenTypeConfiguration() != null) {
                data.set("jwtTokenTypeConfiguration", om.valueToTree(this.getJwtTokenTypeConfiguration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.kendraIndex.KendraIndexUserTokenConfigurations"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            KendraIndexUserTokenConfigurations.Jsii$Proxy that = (KendraIndexUserTokenConfigurations.Jsii$Proxy) o;

            if (this.jsonTokenTypeConfiguration != null ? !this.jsonTokenTypeConfiguration.equals(that.jsonTokenTypeConfiguration) : that.jsonTokenTypeConfiguration != null) return false;
            return this.jwtTokenTypeConfiguration != null ? this.jwtTokenTypeConfiguration.equals(that.jwtTokenTypeConfiguration) : that.jwtTokenTypeConfiguration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.jsonTokenTypeConfiguration != null ? this.jsonTokenTypeConfiguration.hashCode() : 0;
            result = 31 * result + (this.jwtTokenTypeConfiguration != null ? this.jwtTokenTypeConfiguration.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/kendra_index/KendraIndexUserTokenConfigurations.java <==
package com.hashicorp.cdktf.providers.aws.kendra_index;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.220Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.kendraIndex.KendraIndexUserTokenConfigurations")
@software.amazon.jsii.Jsii.Proxy(KendraIndexUserTokenConfigurations.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface KendraIndexUserTokenConfigurations extends software.amazon.jsii.JsiiSerializable {

    /**
     * json_token_type_configuration block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/kendra_index#json_token_type_configuration KendraIndex#json_token_type_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration getJsonTokenTypeConfiguration() {
        return null;
    }

    /**
     * jwt_token_type_configuration block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/kendra_index#jwt_token_type_configuration KendraIndex#jwt_token_type_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration getJwtTokenTypeConfiguration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link KendraIndexUserTokenConfigurations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link KendraIndexUserTokenConfigurations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<KendraIndexUserTokenConfigurations> {
        com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration jsonTokenTypeConfiguration;
        com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration jwtTokenTypeConfiguration;

        /**
         * Sets the value of {@link KendraIndexUserTokenConfigurations#getJsonTokenTypeConfiguration}
         * @param jsonTokenTypeConfiguration json_token_type_configuration block.
         *                                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/kendra_index#json_token_type_configuration KendraIndex#json_token_type_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder jsonTokenTypeConfiguration(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration jsonTokenTypeConfiguration) {
            this.jsonTokenTypeConfiguration = jsonTokenTypeConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link KendraIndexUserTokenConfigurations#getJwtTokenTypeConfiguration}
         * @param jwtTokenTypeConfiguration jwt_token_type_configuration block.
         *                                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/kendra_index#jwt_token_type_configuration KendraIndex#jwt_token_type_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder jwtTokenTypeConfiguration(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration jwtTokenTypeConfiguration) {
            this.jwtTokenTypeConfiguration = jwtTokenTypeConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link KendraIndexUserTokenConfigurations}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public KendraIndexUserTokenConfigurations build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link KendraIndexUserTokenConfigurations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements KendraIndexUserTokenConfigurations {
        private final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration jsonTokenTypeConfiguration;
        private final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration jwtTokenTypeConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.jsonTokenTypeConfiguration = software.amazon.jsii.Kernel.get(this, "jsonTokenTypeConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration.class));
            this.jwtTokenTypeConfiguration = software.amazon.jsii.Kernel.get(this, "jwtTokenTypeConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.jsonTokenTypeConfiguration = builder.jsonTokenTypeConfiguration;
            this.jwtTokenTypeConfiguration = builder.jwtTokenTypeConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJsonTokenTypeConfiguration getJsonTokenTypeConfiguration() {
            return this.jsonTokenTypeConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.kendra_index.KendraIndexUserTokenConfigurationsJwtTokenTypeConfiguration getJwtTokenTypeConfiguration() {
            return this.jwtTokenTypeConfiguration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getJsonTokenTypeConfiguration() != null) {
                data.set("jsonTokenTypeConfiguration", om.valueToTree(this.getJsonTokenTypeConfiguration()));
            }
            if (this.getJwtTokenTypeConfiguration() != null) {
                data.set("jwtTokenTypeConfiguration", om.valueToTree(this.getJwtTokenTypeConfiguration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.kendraIndex.KendraIndexUserTokenConfigurations"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            KendraIndexUserTokenConfigurations.Jsii$Proxy that = (KendraIndexUserTokenConfigurations.Jsii$Proxy) o;

            if (this.jsonTokenTypeConfiguration != null ? !this.jsonTokenTypeConfiguration.equals(that.jsonTokenTypeConfiguration) : that.jsonTokenTypeConfiguration != null) return false;
            return this.jwtTokenTypeConfiguration != null ? this.jwtTokenTypeConfiguration.equals(that.jwtTokenTypeConfiguration) : that.jwtTokenTypeConfiguration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.jsonTokenTypeConfiguration != null ? this.jsonTokenTypeConfiguration.hashCode() : 0;
            result = 31 * result + (this.jwtTokenTypeConfiguration != null ? this.jwtTokenTypeConfiguration.hashCode() : 0);
            return result;
        }
    }
}
